@@ -18,8 +18,9 @@ from ccinput.utilities import (
     get_coord,
     has_dispersion_parameters,
     warn,
+    indexify,
 )
-from ccinput.constants import ATOMIC_NUMBER, SYN_SOFTWARE
+from ccinput.constants import ATOMIC_NUMBER, SYN_SOFTWARE, BASIS_SET_EXCHANGE_KEY
 
 
 class Calculation:
@@ -45,6 +46,7 @@ class Calculation:
         header="File created by ccinput",
         software="",
         file=None,
+        **kwargs,
     ):
         self.xyz = xyz
         self.parameters = parameters
@@ -105,6 +107,7 @@ class Calculation:
         self.name = name
         self.aux_name = aux_name
         self.header = header
+        self.kwargs = kwargs
 
     def verify_charge_mult(self):
         """Verifies that the requested charge and multiplicity are possible for the structure"""
@@ -171,16 +174,16 @@ class Parameters:
 
         if method == "":
             if "functional" in kwargs:
-                method = get_method(kwargs["functional"], self.software)
+                self.method = get_method(kwargs["functional"], self.software)
             elif self.software == "xtb":
-                method = "GFN2-xTB"
+                self.method = "gfn2-xtb"
             else:
                 raise InvalidParameter("No calculation method specified (method='...')")
 
         else:
             self.method = get_method(method, self.software)
 
-        self.theory_level = get_theory_level(method)
+        self.theory_level = get_theory_level(self.method)
 
         if self.theory_level not in ["semiempirical", "xtb", "special"]:
             self.basis_set = get_abs_basis_set(basis_set)
@@ -209,7 +212,34 @@ class Parameters:
 
         self.specifications = specifications
         self.density_fitting = density_fitting
-        self.custom_basis_sets = custom_basis_sets
+
+        dict_cbs = {}
+
+        for entry in custom_basis_sets.split(";"):
+            if entry.strip() == "":
+                continue
+            sentry = entry.split("=")
+
+            if len(sentry) != 2:
+                raise InvalidParameter(f"Invalid custom basis set string: '{entry}'")
+
+            el, bs_str = sentry
+
+            if el in dict_cbs:
+                raise InvalidParameter(
+                    f"The element {el} was specified more than once in the custom basis set string"
+                )
+
+            bs_index = indexify(bs_str)
+
+            if bs_index in BASIS_SET_EXCHANGE_KEY:
+                bs_keyword = BASIS_SET_EXCHANGE_KEY[bs_index]
+            else:
+                bs_keyword = get_abs_basis_set(bs_str)
+
+            dict_cbs[el] = bs_keyword
+
+        self.custom_basis_sets = dict_cbs
         self.kwargs = kwargs
 
     def __eq__(self, other):
@@ -269,7 +299,9 @@ class Constraint:
                 f"Invalid atom index {max(ids)}: larger than the number of atoms"
             )
         if len(ids) != len(set(ids)):
-            raise InvalidParameter(f"The provided atom indices are not all unique")
+            raise InvalidParameter(
+                f"The provided atom indices are not all unique: {ids}"
+            )
 
         if self.scan:
             num_params = 0
