@@ -138,7 +138,7 @@ THEORY_LEVELS = {
     "hf": ["hartreefock"],
     # Some old exotic semi-empirical methods in ORCA are missing
     "semiempirical": ["am1", "pm3", "pm6", "pm7", "mndo"],
-    "xtb": ["gfn2xtb", "gfn1xtb", "gfn0xtb", "gfnff", "gfn2xtbgfnff"],
+    "xtb": ["gfn2xtb", "xtb2", "xtb1", "gfn1xtb", "gfn0xtb", "gfnff", "gfn2xtbgfnff"],
     "special": ["hf3c", "pbeh3c", "r2scan3c", "b973c"],
     "mp2": ["mp2", "rimp2"],
     "cc": [
@@ -858,6 +858,572 @@ SYN_BASIS_SETS = {
     "cbsb7": [],
 }
 
+# Not all basis sets below will be in SYN_BASIS_SETS (to complete).
+# ccinput will still attempt to find the key for the indexified input string.
+# Only orbital basis sets are included below.
+BASIS_SET_EXCHANGE_KEY = {
+    "2zapanr": "2ZaPa-NR",
+    "2zapanrcv": "2ZaPa-NR-CV",
+    "321g": "3-21G",
+    "3zapanr": "3ZaPa-NR",
+    "3zapanrcv": "3ZaPa-NR-CV",
+    "431g": "4-31G",
+    "4zapanr": "4ZaPa-NR",
+    "4zapanrcv": "4ZaPa-NR-CV",
+    "521g": "5-21G",
+    "5zapanr": "5ZaPa-NR",
+    "5zapanrcv": "5ZaPa-NR-CV",
+    "621g": "6-21G",
+    "631++g": "6-31++G",
+    "631++gd": "6-31++G*",
+    "631++gdp": "6-31++G**",
+    "631++gdpj": "6-31++G**-J",
+    "631+g": "6-31+G",
+    "631+gd": "6-31+G*",
+    "631+gdj": "6-31+G*-J",
+    "631+gdp": "6-31+G**",
+    "6311++g": "6-311++G",
+    "6311++g2d2p": "6-311++G(2d,2p)",
+    "6311++g3df3pd": "6-311++G(3df,3pd)",
+    "6311++gd": "6-311++G*",
+    "6311++gdp": "6-311++G**",
+    "6311++gdpj": "6-311++G**-J",
+    "6311+g": "6-311+G",
+    "6311+g2dp": "6-311+G(2d,p)",
+    "6311+gd": "6-311+G*",
+    "6311+gdj": "6-311+G*-J",
+    "6311+gdp": "6-311+G**",
+    "6311g": "6-311G",
+    "6311g2df2pd": "6-311G(2df,2pd)",
+    "6311gdp": "6-311G(d,p)",
+    "6311gj": "6-311G-J",
+    "6311gd": "6-311G*",
+    "6311gdp": "6-311G**",
+    "6311xxgdp": "6-311xxG(d,p)",
+    "631g": "6-31G",
+    "631g2dfp": "6-31G(2df,p)",
+    "631g3df3pd": "6-31G(3df,3pd)",
+    "631gdp": "6-31G(d,p)",
+    "631gblaudeau": "6-31G-Blaudeau",
+    "631gj": "6-31G-J",
+    "631gd": "6-31G*",
+    "631gdblaudeau": "6-31G*-Blaudeau",
+    "631gdp": "6-31G**",
+    "6zapanr": "6ZaPa-NR",
+    "7zapanr": "7ZaPa-NR",
+    "acv2zj": "acv2z-J",
+    "acv3zj": "acv3z-J",
+    "acv4zj": "acv4z-J",
+    "ahgbs5": "AHGBS-5",
+    "ahgbs7": "AHGBS-7",
+    "ahgbs9": "AHGBS-9",
+    "ahgbsp15": "AHGBSP1-5",
+    "ahgbsp17": "AHGBSP1-7",
+    "ahgbsp19": "AHGBSP1-9",
+    "ahgbsp25": "AHGBSP2-5",
+    "ahgbsp27": "AHGBSP2-7",
+    "ahgbsp29": "AHGBSP2-9",
+    "ahgbsp35": "AHGBSP3-5",
+    "ahgbsp37": "AHGBSP3-7",
+    "ahgbsp39": "AHGBSP3-9",
+    "ahlrichspvdz": "AhlrichspVDZ",
+    "ahlrichstzv": "AhlrichsTZV",
+    "ahlrichsvdz": "AhlrichsVDZ",
+    "ahlrichsvtz": "AhlrichsVTZ",
+    "anodk3": "ANO-DK3",
+    "anor": "ANO-R",
+    "anor0": "ANO-R0",
+    "anor1": "ANO-R1",
+    "anor2": "ANO-R2",
+    "anor3": "ANO-R3",
+    "anorcc": "ANO-RCC",
+    "anorccmb": "ANO-RCC-MB",
+    "anorccvdz": "ANO-RCC-VDZ",
+    "anorccvdzp": "ANO-RCC-VDZP",
+    "anorccvqzp": "ANO-RCC-VQZP",
+    "anorccvtz": "ANO-RCC-VTZ",
+    "anorccvtzp": "ANO-RCC-VTZP",
+    "anovtdz": "ANO-VT-DZ",
+    "anovtqz": "ANO-VT-QZ",
+    "anovttz": "ANO-VT-TZ",
+    "aprccpvq+dz": "apr-cc-pV(Q+d)Z",
+    "atzpzora": "ATZP-ZORA",
+    "augccpcv5z": "aug-cc-pCV5Z",
+    "augccpcvdz": "aug-cc-pCVDZ",
+    "augccpcvdzdk": "aug-cc-pCVDZ-DK",
+    "augccpcvqz": "aug-cc-pCVQZ",
+    "augccpcvqzdk": "aug-cc-pCVQZ-DK",
+    "augccpcvtz": "aug-cc-pCVTZ",
+    "augccpcvtzdk": "aug-cc-pCVTZ-DK",
+    "augccpv5+dz": "aug-cc-pV(5+d)Z",
+    "augccpvd+dz": "aug-cc-pV(D+d)Z",
+    "augccpvq+dz": "aug-cc-pV(Q+d)Z",
+    "augccpvt+dz": "aug-cc-pV(T+d)Z",
+    "augccpv5z": "aug-cc-pV5Z",
+    "augccpv5zdk": "aug-cc-pV5Z-DK",
+    "augccpv5zpp": "aug-cc-pV5Z-PP",
+    "augccpv6z": "aug-cc-pV6Z",
+    "augccpv7z": "aug-cc-pV7Z",
+    "augccpvdz": "aug-cc-pVDZ",
+    "augccpvdzdk": "aug-cc-pVDZ-DK",
+    "augccpvdzdk3": "aug-cc-pVDZ-DK3",
+    "augccpvdzpp": "aug-cc-pVDZ-PP",
+    "augccpvdzx2c": "aug-cc-pVDZ-X2C",
+    "augccpvqz": "aug-cc-pVQZ",
+    "augccpvqzdk": "aug-cc-pVQZ-DK",
+    "augccpvqzdk3": "aug-cc-pVQZ-DK3",
+    "augccpvqzpp": "aug-cc-pVQZ-PP",
+    "augccpvqzx2c": "aug-cc-pVQZ-X2C",
+    "augccpvtz": "aug-cc-pVTZ",
+    "augccpvtzdk": "aug-cc-pVTZ-DK",
+    "augccpvtzdk3": "aug-cc-pVTZ-DK3",
+    "augccpvtzj": "aug-cc-pVTZ-J",
+    "augccpvtzpp": "aug-cc-pVTZ-PP",
+    "augccpvtzx2c": "aug-cc-pVTZ-X2C",
+    "augccpwcv5z": "aug-cc-pwCV5Z",
+    "augccpwcv5zdk": "aug-cc-pwCV5Z-DK",
+    "augccpwcv5zpp": "aug-cc-pwCV5Z-PP",
+    "augccpwcvdz": "aug-cc-pwCVDZ",
+    "augccpwcvdzdk3": "aug-cc-pwCVDZ-DK3",
+    "augccpwcvdzpp": "aug-cc-pwCVDZ-PP",
+    "augccpwcvdzx2c": "aug-cc-pwCVDZ-X2C",
+    "augccpwcvqz": "aug-cc-pwCVQZ",
+    "augccpwcvqzdk": "aug-cc-pwCVQZ-DK",
+    "augccpwcvqzdk3": "aug-cc-pwCVQZ-DK3",
+    "augccpwcvqzpp": "aug-cc-pwCVQZ-PP",
+    "augccpwcvqzx2c": "aug-cc-pwCVQZ-X2C",
+    "augccpwcvtz": "aug-cc-pwCVTZ",
+    "augccpwcvtzdk": "aug-cc-pwCVTZ-DK",
+    "augccpwcvtzdk3": "aug-cc-pwCVTZ-DK3",
+    "augccpwcvtzpp": "aug-cc-pwCVTZ-PP",
+    "augccpwcvtzx2c": "aug-cc-pwCVTZ-X2C",
+    "augccx5z": "aug-ccX-5Z",
+    "augccxdz": "aug-ccX-DZ",
+    "augccxqz": "aug-ccX-QZ",
+    "augccxtz": "aug-ccX-TZ",
+    "augmccpv5z": "aug-mcc-pV5Z",
+    "augmccpv6z": "aug-mcc-pV6Z",
+    "augmccpv7z": "aug-mcc-pV7Z",
+    "augmccpv8z": "aug-mcc-pV8Z",
+    "augmccpvqz": "aug-mcc-pVQZ",
+    "augmccpvtz": "aug-mcc-pVTZ",
+    "augpc0": "aug-pc-0",
+    "augpc1": "aug-pc-1",
+    "augpc2": "aug-pc-2",
+    "augpc3": "aug-pc-3",
+    "augpc4": "aug-pc-4",
+    "augpch1": "aug-pcH-1",
+    "augpch2": "aug-pcH-2",
+    "augpch3": "aug-pcH-3",
+    "augpch4": "aug-pcH-4",
+    "augpcj0": "aug-pcJ-0",
+    "augpcj02006": "aug-pcJ-0_2006",
+    "augpcj1": "aug-pcJ-1",
+    "augpcj12006": "aug-pcJ-1_2006",
+    "augpcj2": "aug-pcJ-2",
+    "augpcj22006": "aug-pcJ-2_2006",
+    "augpcj3": "aug-pcJ-3",
+    "augpcj32006": "aug-pcJ-3_2006",
+    "augpcj4": "aug-pcJ-4",
+    "augpcj42006": "aug-pcJ-4_2006",
+    "augpcs0": "aug-pcS-0",
+    "augpcs1": "aug-pcS-1",
+    "augpcs2": "aug-pcS-2",
+    "augpcs3": "aug-pcS-3",
+    "augpcs4": "aug-pcS-4",
+    "augpcseg0": "aug-pcseg-0",
+    "augpcseg1": "aug-pcseg-1",
+    "augpcseg2": "aug-pcseg-2",
+    "augpcseg3": "aug-pcseg-3",
+    "augpcseg4": "aug-pcseg-4",
+    "augpcsseg0": "aug-pcSseg-0",
+    "augpcsseg1": "aug-pcSseg-1",
+    "augpcsseg2": "aug-pcSseg-2",
+    "augpcsseg3": "aug-pcSseg-3",
+    "augpcsseg4": "aug-pcSseg-4",
+    "augpcx1": "aug-pcX-1",
+    "augpcx2": "aug-pcX-2",
+    "augpcx3": "aug-pcX-3",
+    "augpcx4": "aug-pcX-4",
+    "augpv7z": "aug-pV7Z",
+    "binning641": "binning641",
+    "binning641d": "binning641(d)",
+    "binning641df": "binning641(df)",
+    "binning641+": "binning641+",
+    "binning641+d": "binning641+(d)",
+    "binning641+df": "binning641+(df)",
+    "binning962": "binning962",
+    "binning962d": "binning962(d)",
+    "binning962df": "binning962(df)",
+    "binning962+": "binning962+",
+    "binning962+d": "binning962+(d)",
+    "binning962+df": "binning962+(df)",
+    "ccpcv5z": "cc-pCV5Z",
+    "ccpcvdz": "cc-pCVDZ",
+    "ccpcvdzdk": "cc-pCVDZ-DK",
+    "ccpcvdzf12": "cc-pCVDZ-F12",
+    "ccpcvqz": "cc-pCVQZ",
+    "ccpcvqzdk": "cc-pCVQZ-DK",
+    "ccpcvqzf12": "cc-pCVQZ-F12",
+    "ccpcvtz": "cc-pCVTZ",
+    "ccpcvtzdk": "cc-pCVTZ-DK",
+    "ccpcvtzf12": "cc-pCVTZ-F12",
+    "ccpv5+dz": "cc-pV(5+d)Z",
+    "ccpvd+dz": "cc-pV(D+d)Z",
+    "ccpvq+dz": "cc-pV(Q+d)Z",
+    "ccpvt+dz": "cc-pV(T+d)Z",
+    "ccpv5z": "cc-pV5Z",
+    "ccpv5zfisffw": "cc-pV5Z(fi/sf/fw)",
+    "ccpv5zfisflc": "cc-pV5Z(fi/sf/lc)",
+    "ccpv5zfisfsc": "cc-pV5Z(fi/sf/sc)",
+    "ccpv5zptsffw": "cc-pV5Z(pt/sf/fw)",
+    "ccpv5zptsflc": "cc-pV5Z(pt/sf/lc)",
+    "ccpv5zptsfsc": "cc-pV5Z(pt/sf/sc)",
+    "ccpv5zdk": "cc-pV5Z-DK",
+    "ccpv5zf12": "cc-pV5Z-F12",
+    "ccpv5zf12rev2": "cc-pV5Z-F12(rev2)",
+    "ccpv5zpp": "cc-pV5Z-PP",
+    "ccpv6z": "cc-pV6Z",
+    "ccpv8z": "cc-pV8Z",
+    "ccpv9z": "cc-pV9Z",
+    "ccpvdz": "cc-pVDZ",
+    "ccpvdzfisffw": "cc-pVDZ(fi/sf/fw)",
+    "ccpvdzfisflc": "cc-pVDZ(fi/sf/lc)",
+    "ccpvdzfisfsc": "cc-pVDZ(fi/sf/sc)",
+    "ccpvdzptsffw": "cc-pVDZ(pt/sf/fw)",
+    "ccpvdzptsflc": "cc-pVDZ(pt/sf/lc)",
+    "ccpvdzptsfsc": "cc-pVDZ(pt/sf/sc)",
+    "ccpvdzsegopt": "cc-pVDZ(seg-opt)",
+    "ccpvdzdk": "cc-pVDZ-DK",
+    "ccpvdzdk3": "cc-pVDZ-DK3",
+    "ccpvdzf12": "cc-pVDZ-F12",
+    "ccpvdzf12rev2": "cc-pVDZ-F12(rev2)",
+    "ccpvdzpp": "cc-pVDZ-PP",
+    "ccpvdzx2c": "cc-pVDZ-X2C",
+    "ccpvqz": "cc-pVQZ",
+    "ccpvqzfisffw": "cc-pVQZ(fi/sf/fw)",
+    "ccpvqzfisflc": "cc-pVQZ(fi/sf/lc)",
+    "ccpvqzfisfsc": "cc-pVQZ(fi/sf/sc)",
+    "ccpvqzptsffw": "cc-pVQZ(pt/sf/fw)",
+    "ccpvqzptsflc": "cc-pVQZ(pt/sf/lc)",
+    "ccpvqzptsfsc": "cc-pVQZ(pt/sf/sc)",
+    "ccpvqzsegopt": "cc-pVQZ(seg-opt)",
+    "ccpvqzdk": "cc-pVQZ-DK",
+    "ccpvqzdk3": "cc-pVQZ-DK3",
+    "ccpvqzf12": "cc-pVQZ-F12",
+    "ccpvqzf12rev2": "cc-pVQZ-F12(rev2)",
+    "ccpvqzpp": "cc-pVQZ-PP",
+    "ccpvqzx2c": "cc-pVQZ-X2C",
+    "ccpvtz": "cc-pVTZ",
+    "ccpvtzfisffw": "cc-pVTZ(fi/sf/fw)",
+    "ccpvtzfisflc": "cc-pVTZ(fi/sf/lc)",
+    "ccpvtzfisfsc": "cc-pVTZ(fi/sf/sc)",
+    "ccpvtzptsffw": "cc-pVTZ(pt/sf/fw)",
+    "ccpvtzptsflc": "cc-pVTZ(pt/sf/lc)",
+    "ccpvtzptsfsc": "cc-pVTZ(pt/sf/sc)",
+    "ccpvtzsegopt": "cc-pVTZ(seg-opt)",
+    "ccpvtzdk": "cc-pVTZ-DK",
+    "ccpvtzdk3": "cc-pVTZ-DK3",
+    "ccpvtzf12": "cc-pVTZ-F12",
+    "ccpvtzf12rev2": "cc-pVTZ-F12(rev2)",
+    "ccpvtzpp": "cc-pVTZ-PP",
+    "ccpvtzx2c": "cc-pVTZ-X2C",
+    "ccpwcv5z": "cc-pwCV5Z",
+    "ccpwcv5zdk": "cc-pwCV5Z-DK",
+    "ccpwcv5zpp": "cc-pwCV5Z-PP",
+    "ccpwcvdz": "cc-pwCVDZ",
+    "ccpwcvdzdk3": "cc-pwCVDZ-DK3",
+    "ccpwcvdzpp": "cc-pwCVDZ-PP",
+    "ccpwcvdzx2c": "cc-pwCVDZ-X2C",
+    "ccpwcvqz": "cc-pwCVQZ",
+    "ccpwcvqzdk": "cc-pwCVQZ-DK",
+    "ccpwcvqzdk3": "cc-pwCVQZ-DK3",
+    "ccpwcvqzpp": "cc-pwCVQZ-PP",
+    "ccpwcvqzx2c": "cc-pwCVQZ-X2C",
+    "ccpwcvtz": "cc-pwCVTZ",
+    "ccpwcvtzdk": "cc-pwCVTZ-DK",
+    "ccpwcvtzdk3": "cc-pwCVTZ-DK3",
+    "ccpwcvtzpp": "cc-pwCVTZ-PP",
+    "ccpwcvtzx2c": "cc-pwCVTZ-X2C",
+    "ccemd2": "ccemd-2",
+    "ccemd3": "ccemd-3",
+    "ccjpv5z": "ccJ-pV5Z",
+    "ccjpvdz": "ccJ-pVDZ",
+    "ccjpvqz": "ccJ-pVQZ",
+    "ccjpvtz": "ccJ-pVTZ",
+    "ccx5z": "ccX-5Z",
+    "ccxdz": "ccX-DZ",
+    "ccxqz": "ccX-QZ",
+    "ccxtz": "ccX-TZ",
+    "coemd2": "coemd-2",
+    "coemd3": "coemd-3",
+    "coemd4": "coemd-4",
+    "coemdref": "coemd-ref",
+    "colognedkh2": "CologneDKH2",
+    "crenbl": "CRENBL",
+    "crenblecp": "CRENBLECP",
+    "crenbs": "CRENBS",
+    "crenbsecp": "CRENBSECP",
+    "daugccpv5z": "d-aug-cc-pV5Z",
+    "daugccpv6z": "d-aug-cc-pV6Z",
+    "daugccpvdz": "d-aug-cc-pVDZ",
+    "daugccpvqz": "d-aug-cc-pVQZ",
+    "daugccpvtz": "d-aug-cc-pVTZ",
+    "def2ecp": "def2-ECP",
+    "def2qzvp": "def2-QZVP",
+    "def2qzvpd": "def2-QZVPD",
+    "def2qzvpp": "def2-QZVPP",
+    "def2qzvppd": "def2-QZVPPD",
+    "def2svp": "def2-SV(P)",
+    "def2svp": "def2-SVP",
+    "def2svpd": "def2-SVPD",
+    "def2tzvp": "def2-TZVP",
+    "def2tzvpd": "def2-TZVPD",
+    "def2tzvpp": "def2-TZVPP",
+    "def2tzvppd": "def2-TZVPPD",
+    "demon2kdzvpgga": "deMon2k-DZVP-GGA",
+    "dfo+nrlmol": "DFO+-NRLMOL",
+    "dfo1": "DFO-1",
+    "dfo1bhs": "DFO-1-BHS",
+    "dfo2": "DFO-2",
+    "dfonrlmol": "DFO-NRLMOL",
+    "dgaussdzvp": "dgauss-dzvp",
+    "dgaussdzvp2": "dgauss-dzvp2",
+    "dgausstzvp": "dgauss-tzvp",
+    "dhfecp": "dhf-ECP",
+    "dhfqzvp": "dhf-QZVP",
+    "dhfqzvpp": "dhf-QZVPP",
+    "dhfsvp": "dhf-SV(P)",
+    "dhfsvp": "dhf-SVP",
+    "dhftzvp": "dhf-TZVP",
+    "dhftzvpp": "dhf-TZVPP",
+    "dzdunninghay": "DZ(Dunning-Hay)",
+    "dz+doublerydbergdunninghay": "DZ+DoubleRydberg(Dunning-Hay)",
+    "dz+rydbergdunninghay": "DZ+Rydberg(Dunning-Hay)",
+    "dzpdunninghay": "DZP(Dunning-Hay)",
+    "dzp+diffusedunninghay": "DZP+Diffuse(Dunning-Hay)",
+    "dzp+rydbergdunninghay": "DZP+Rydberg(Dunning-Hay)",
+    "fano5z": "FANO-5Z",
+    "fano6z": "FANO-6Z",
+    "fanodz": "FANO-DZ",
+    "fanoqz": "FANO-QZ",
+    "fanotz": "FANO-TZ",
+    "hgbs5": "HGBS-5",
+    "hgbs7": "HGBS-7",
+    "hgbs9": "HGBS-9",
+    "hgbsp15": "HGBSP1-5",
+    "hgbsp17": "HGBSP1-7",
+    "hgbsp19": "HGBSP1-9",
+    "hgbsp25": "HGBSP2-5",
+    "hgbsp27": "HGBSP2-7",
+    "hgbsp29": "HGBSP2-9",
+    "hgbsp35": "HGBSP3-5",
+    "hgbsp37": "HGBSP3-7",
+    "hgbsp39": "HGBSP3-9",
+    "igloii": "IGLO-II",
+    "igloiii": "IGLO-III",
+    "jgaussdzp": "jgauss-dzp",
+    "jgaussqz2p": "jgauss-qz2p",
+    "jgaussqzp": "jgauss-qzp",
+    "jgausstzp1": "jgauss-tzp1",
+    "jgausstzp2": "jgauss-tzp2",
+    "jorge5zp": "jorge-5ZP",
+    "jorge5zpdkh": "jorge-5ZP-DKH",
+    "jorge6zp": "jorge-6ZP",
+    "jorge6zpdkh": "jorge-6ZP-DKH",
+    "jorgea5zp": "jorge-A5ZP",
+    "jorgeadzp": "jorge-ADZP",
+    "jorgeaqzp": "jorge-AQZP",
+    "jorgeatzp": "jorge-ATZP",
+    "jorgedzp": "jorge-DZP",
+    "jorgedzpdkh": "jorge-DZP-DKH",
+    "jorgeqzp": "jorge-QZP",
+    "jorgeqzpdkh": "jorge-QZP-DKH",
+    "jorgetzp": "jorge-TZP",
+    "jorgetzpdkh": "jorge-TZP-DKH",
+    "julccpvd+dz": "jul-cc-pV(D+d)Z",
+    "julccpvq+dz": "jul-cc-pV(Q+d)Z",
+    "julccpvt+dz": "jul-cc-pV(T+d)Z",
+    "junccpvd+dz": "jun-cc-pV(D+d)Z",
+    "junccpvq+dz": "jun-cc-pV(Q+d)Z",
+    "junccpvt+dz": "jun-cc-pV(T+d)Z",
+    "kogaunpolarized": "Kogaunpolarized",
+    "lanl08": "LANL08",
+    "lanl08d": "LANL08(d)",
+    "lanl08f": "LANL08(f)",
+    "lanl08+": "LANL08+",
+    "lanl2dz": "LANL2DZ",
+    "lanl2dzecp": "LANL2DZECP",
+    "lanl2dzdp": "LANL2DZdp",
+    "lanl2tz": "LANL2TZ",
+    "lanl2tzf": "LANL2TZ(f)",
+    "lanl2tz+": "LANL2TZ+",
+    "m631g": "m6-31G",
+    "m631gd": "m6-31G*",
+    "maugccpvd+dz": "maug-cc-pV(D+d)Z",
+    "maugccpvq+dz": "maug-cc-pV(Q+d)Z",
+    "maugccpvt+dz": "maug-cc-pV(T+d)Z",
+    "mayccpvq+dz": "may-cc-pV(Q+d)Z",
+    "mayccpvt+dz": "may-cc-pV(T+d)Z",
+    "midi": "MIDI",
+    "midi": "MIDI!",
+    "midix": "MIDIX",
+    "mini": "MINI",
+    "modifiedlanl2dz": "modified-LANL2DZ",
+    "nasaamesano": "NASAAmesANO",
+    "nasaamesano2": "NASAAmesANO2",
+    "nasaamesccpcv5z": "NASAAmescc-pCV5Z",
+    "nasaamesccpcvqz": "NASAAmescc-pCVQZ",
+    "nasaamesccpcvtz": "NASAAmescc-pCVTZ",
+    "nasaamesccpv5z": "NASAAmescc-pV5Z",
+    "nasaamesccpvqz": "NASAAmescc-pVQZ",
+    "nasaamesccpvtz": "NASAAmescc-pVTZ",
+    "nlov": "NLO-V",
+    "nmrdkhtz2p": "NMR-DKH(TZ2P)",
+    "orp": "ORP",
+    "partridgeuncontracted1": "PartridgeUncontracted1",
+    "partridgeuncontracted2": "PartridgeUncontracted2",
+    "partridgeuncontracted3": "PartridgeUncontracted3",
+    "partridgeuncontracted4": "PartridgeUncontracted4",
+    "pc0": "pc-0",
+    "pc1": "pc-1",
+    "pc2": "pc-2",
+    "pc3": "pc-3",
+    "pc4": "pc-4",
+    "pcemd2": "pcemd-2",
+    "pcemd3": "pcemd-3",
+    "pcemd4": "pcemd-4",
+    "pch1": "pcH-1",
+    "pch2": "pcH-2",
+    "pch3": "pcH-3",
+    "pch4": "pcH-4",
+    "pcj0": "pcJ-0",
+    "pcj02006": "pcJ-0_2006",
+    "pcj1": "pcJ-1",
+    "pcj12006": "pcJ-1_2006",
+    "pcj2": "pcJ-2",
+    "pcj22006": "pcJ-2_2006",
+    "pcj3": "pcJ-3",
+    "pcj32006": "pcJ-3_2006",
+    "pcj4": "pcJ-4",
+    "pcj42006": "pcJ-4_2006",
+    "pcs0": "pcS-0",
+    "pcs1": "pcS-1",
+    "pcs2": "pcS-2",
+    "pcs3": "pcS-3",
+    "pcs4": "pcS-4",
+    "pcseg0": "pcseg-0",
+    "pcseg1": "pcseg-1",
+    "pcseg2": "pcseg-2",
+    "pcseg3": "pcseg-3",
+    "pcseg4": "pcseg-4",
+    "pcsseg0": "pcSseg-0",
+    "pcsseg1": "pcSseg-1",
+    "pcsseg2": "pcSseg-2",
+    "pcsseg3": "pcSseg-3",
+    "pcsseg4": "pcSseg-4",
+    "pcx1": "pcX-1",
+    "pcx2": "pcX-2",
+    "pcx3": "pcX-3",
+    "pcx4": "pcX-4",
+    "psbkjc": "pSBKJC",
+    "ptmdzp": "Pt-mDZP",
+    "pv6z": "pV6Z",
+    "pv7z": "pV7Z",
+    "roosaugmenteddoublezetaano": "RoosAugmentedDoubleZetaANO",
+    "roosaugmentedtriplezetaano": "RoosAugmentedTripleZetaANO",
+    "s321g": "s3-21G",
+    "s321gd": "s3-21G*",
+    "s631g": "s6-31G",
+    "s631gd": "s6-31G*",
+    "sadlejpvtz": "SadlejpVTZ",
+    "sadlej+": "Sadlej+",
+    "sapporodkh3dzp": "Sapporo-DKH3-DZP",
+    "sapporodkh3dzp2012": "Sapporo-DKH3-DZP-2012",
+    "sapporodkh3dzp2012diffuse": "Sapporo-DKH3-DZP-2012-diffuse",
+    "sapporodkh3dzpdiffuse": "Sapporo-DKH3-DZP-diffuse",
+    "sapporodkh3qzp": "Sapporo-DKH3-QZP",
+    "sapporodkh3qzp2012": "Sapporo-DKH3-QZP-2012",
+    "sapporodkh3qzp2012diffuse": "Sapporo-DKH3-QZP-2012-diffuse",
+    "sapporodkh3qzpdiffuse": "Sapporo-DKH3-QZP-diffuse",
+    "sapporodkh3tzp": "Sapporo-DKH3-TZP",
+    "sapporodkh3tzp2012": "Sapporo-DKH3-TZP-2012",
+    "sapporodkh3tzp2012diffuse": "Sapporo-DKH3-TZP-2012-diffuse",
+    "sapporodkh3tzpdiffuse": "Sapporo-DKH3-TZP-diffuse",
+    "sapporodzp": "Sapporo-DZP",
+    "sapporodzp2012": "Sapporo-DZP-2012",
+    "sapporodzp2012diffuse": "Sapporo-DZP-2012-diffuse",
+    "sapporodzpdiffuse": "Sapporo-DZP-diffuse",
+    "sapporoqzp": "Sapporo-QZP",
+    "sapporoqzp2012": "Sapporo-QZP-2012",
+    "sapporoqzp2012diffuse": "Sapporo-QZP-2012-diffuse",
+    "sapporoqzpdiffuse": "Sapporo-QZP-diffuse",
+    "sapporotzp": "Sapporo-TZP",
+    "sapporotzp2012": "Sapporo-TZP-2012",
+    "sapporotzp2012diffuse": "Sapporo-TZP-2012-diffuse",
+    "sapporotzpdiffuse": "Sapporo-TZP-diffuse",
+    "sarcdkh2": "SARC-DKH2",
+    "sarczora": "SARC-ZORA",
+    "sarc2qzvdkh2": "SARC2-QZV-DKH2",
+    "sarc2qzvzora": "SARC2-QZV-ZORA",
+    "sarc2qzvpdkh2": "SARC2-QZVP-DKH2",
+    "sarc2qzvpzora": "SARC2-QZVP-ZORA",
+    "sbkjcpolarizedp2dlfk": "SBKJCPolarized(p,2d)-LFK",
+    "sbkjcecp": "SBKJC-ECP",
+    "sbkjcvdz": "SBKJC-VDZ",
+    "sbo4dzd3g": "SBO4-DZ(d)-3G",
+    "sbo4dzdp3g": "SBO4-DZ(d,p)-3G",
+    "sbo4sz3g": "SBO4-SZ-3G",
+    "scaledmini": "ScaledMINI",
+    "sto2g": "STO-2G",
+    "sto3g": "STO-3G",
+    "sto3g*": "STO-3G*",
+    "sto4g": "STO-4G",
+    "sto5g": "STO-5G",
+    "sto6g": "STO-6G",
+    "stuttgartrlc": "StuttgartRLC",
+    "stuttgartrlcecp": "StuttgartRLCECP",
+    "stuttgartrsc1997": "StuttgartRSC1997",
+    "stuttgartrsc1997ecp": "StuttgartRSC1997ECP",
+    "stuttgartrscano": "StuttgartRSCANO",
+    "stuttgartrscsegmented+ecp": "StuttgartRSCSegmented+ECP",
+    "svdunninghay": "SV(Dunning-Hay)",
+    "sv+doublerydbergdunninghay": "SV+DoubleRydberg(Dunning-Hay)",
+    "sv+rydbergdunninghay": "SV+Rydberg(Dunning-Hay)",
+    "svpdunninghay": "SVP(Dunning-Hay)",
+    "svp+diffusedunninghay": "SVP+Diffuse(Dunning-Hay)",
+    "svp+diffuse+rydbergdunninghay": "SVP+Diffuse+Rydberg(Dunning-Hay)",
+    "svp+rydbergdunninghay": "SVP+Rydberg(Dunning-Hay)",
+    "tzdunninghay": "TZ(Dunning-Hay)",
+    "tzpzora": "TZP-ZORA",
+    "ugbs": "UGBS",
+    "unccemdref": "un-ccemd-ref",
+    "unpcemdref": "un-pcemd-ref",
+    "wachters+f": "Wachters+f",
+    "wtbs": "WTBS",
+    "x2cqzvpall": "x2c-QZVPall",
+    "x2cqzvpall2c": "x2c-QZVPall-2c",
+    "x2cqzvpall2cs": "x2c-QZVPall-2c-s",
+    "x2cqzvpalls": "x2c-QZVPall-s",
+    "x2cqzvppall": "x2c-QZVPPall",
+    "x2cqzvppall2c": "x2c-QZVPPall-2c",
+    "x2cqzvppall2cs": "x2c-QZVPPall-2c-s",
+    "x2cqzvppalls": "x2c-QZVPPall-s",
+    "x2csvpall": "x2c-SV(P)all",
+    "x2csvpall2c": "x2c-SV(P)all-2c",
+    "x2csvpalls": "x2c-SV(P)all-s",
+    "x2csvpall": "x2c-SVPall",
+    "x2csvpall2c": "x2c-SVPall-2c",
+    "x2csvpalls": "x2c-SVPall-s",
+    "x2ctzvpall": "x2c-TZVPall",
+    "x2ctzvpall2c": "x2c-TZVPall-2c",
+    "x2ctzvpalls": "x2c-TZVPall-s",
+    "x2ctzvppall": "x2c-TZVPPall",
+    "x2ctzvppall2c": "x2c-TZVPPall-2c",
+    "x2ctzvppalls": "x2c-TZVPPall-s",
+}
+
+
 SOFTWARE_METHODS = {
     "orca": {
         "hfs": "HFS",
