@@ -2,7 +2,11 @@ import basis_set_exchange
 
 from ccinput.constants import CalcType, ATOMIC_NUMBER, LOWERCASE_ATOMIC_SYMBOLS
 from ccinput.utilities import get_method, get_basis_set, get_solvent, clean_xyz
-from ccinput.exceptions import InvalidParameter, UnimplementedError
+from ccinput.exceptions import (
+    InvalidParameter,
+    UnimplementedError,
+    ImpossibleCalculation,
+)
 
 
 class OrcaCalculation:
@@ -29,6 +33,19 @@ class OrcaCalculation:
 
     input_file = ""
 
+    CALC_TYPES = [
+        CalcType.SP,
+        CalcType.OPT,
+        CalcType.CONSTR_OPT,
+        CalcType.FREQ,
+        CalcType.TS,
+        CalcType.MEP,
+        CalcType.NMR,
+        CalcType.UVVIS,
+        CalcType.MO,
+        CalcType.OPTFREQ,
+    ]
+
     def __init__(self, calc):
         self.calc = calc
         self.has_scan = False
@@ -42,6 +59,15 @@ class OrcaCalculation:
         self.specifications = {}
         self.solvation_radii = {}
 
+        if self.calc.type not in self.CALC_TYPES:
+            raise ImpossibleCalculation(
+                f"ORCA 5 does not support calculations of type {self.calc.type}"
+            )
+
+        if self.calc.type == CalcType.UVVIS:
+            raise UnimplementedError(
+                f"UV-Vis/TD-DFT calculations are currently not interfaced for ORCA 5"
+            )
         self.handle_specifications()
 
         self.handle_command()
@@ -112,6 +138,8 @@ class OrcaCalculation:
             self.command_line = "OPT FREQ "
         elif self.calc.type == CalcType.TS:
             self.command_line = "OPTTS "
+            if self.calc.parameters.theory_level != "xtb":
+                self.blocks.append("%geom\nCalc_Hess true\nend")
         elif self.calc.type == CalcType.MO:
             self.command_line = "SP "
             struct = clean_xyz(self.calc.xyz)
@@ -207,15 +235,9 @@ class OrcaCalculation:
             self.command_line += f"{method} "
 
     def handle_custom_basis_sets(self):
-        if self.calc.parameters.custom_basis_sets == "":
+        if len(self.calc.parameters.custom_basis_sets) == 0:
             return
 
-        entries = [
-            i.strip()
-            for i in self.calc.parameters.custom_basis_sets.split(";")
-            if i.strip() != ""
-        ]
-
         unique_atoms = []
         for line in self.calc.xyz.split("\n"):
             if line.strip() == "":
@@ -229,14 +251,7 @@ class OrcaCalculation:
         end"""
 
         custom_bs = ""
-        for entry in entries:
-            sentry = entry.split("=")
-
-            if len(sentry) != 2:
-                raise InvalidParameter("Invalid custom basis set string")
-
-            el, bs_keyword = sentry
-
+        for el, bs_keyword in self.calc.parameters.custom_basis_sets.items():
             if el not in unique_atoms:
                 continue
 
