@@ -2,7 +2,7 @@ import os
 
 from ccinput.constants import CalcType, ATOMIC_NUMBER, LOWERCASE_ATOMIC_SYMBOLS
 from ccinput.utilities import get_solvent
-from ccinput.exceptions import InvalidParameter
+from ccinput.exceptions import InvalidParameter, ImpossibleCalculation
 
 
 class XtbCalculation:
@@ -28,6 +28,10 @@ class XtbCalculation:
         self.force_constant = 1.0
         self.confirmed_specifications = ""
 
+        if self.calc.type not in self.EXECUTABLES:
+            raise ImpossibleCalculation(
+                f"xtb does not support calculations of type {self.calc.type}"
+            )
         self.handle_command()
         self.handle_specifications()
 
@@ -40,8 +44,20 @@ class XtbCalculation:
 
         self.create_command()
 
+    def get_output_name(self):
+        if self.calc.file:
+            return os.path.basename(self.calc.file)
+        else:
+            return self.calc.name + ".xyz"
+
     def handle_parameters(self):
         if self.calc.parameters.solvent != "":
+            if (
+                self.calc.parameters.solvation_radii != ""
+                or self.calc.parameters.custom_solvation_radii != ""
+            ):
+                raise InvalidParameter("Cannot change the solvation radii in xtb")
+
             try:
                 solvent_keyword = get_solvent(
                     self.calc.parameters.solvent, self.calc.parameters.software
@@ -55,9 +71,7 @@ class XtbCalculation:
                 self.main_command += f"--alpb {solvent_keyword} "
             else:
                 raise InvalidParameter(
-                    "Invalid solvation method for xtb: {}".format(
-                        self.calc.parameters.solvation_model
-                    )
+                    f"Invalid solvation method for xtb: {self.calc.parameters.solvation_model}"
                 )
 
         if self.calc.charge != 0:
@@ -119,7 +133,8 @@ class XtbCalculation:
             raise InvalidParameter("No constraint in constrained optimisation mode")
 
         num_atoms = len(self.calc.xyz.split("\n"))
-        input_file_name = os.path.basename(self.calc.file)
+
+        input_file_name = self.get_output_name()
 
         self.input_file += "$constrain\n"
         self.input_file += f"force constant={self.force_constant}\n"
@@ -285,23 +300,25 @@ class XtbCalculation:
     def handle_command(self):
         self.program = self.EXECUTABLES[self.calc.type]
 
+        if "output" in self.calc.kwargs and self.calc.kwargs["output"]:
+            aux_input = self.calc.kwargs["output"]
+        else:
+            aux_input = "input"
+
         if self.calc.type == CalcType.OPT:
             self.specifications = "--opt tight "
             self.main_command += "--opt "
         elif self.calc.type == CalcType.OPTFREQ:
             self.main_command = "--ohess "  # Not sure if the tightness will be parsed
         elif self.calc.type == CalcType.CONSTR_CONF_SEARCH:
-            self.main_command += "-cinp input "
+            self.main_command += f"-cinp {aux_input} "
         elif self.calc.type == CalcType.CONSTR_OPT:
-            self.main_command += "--opt --input input "
+            self.main_command += f"--opt --input {aux_input} "
         elif self.calc.type == CalcType.FREQ:
             self.main_command += "--hess "
 
     def create_command(self):
-        if self.calc.file:
-            input_file_name = os.path.basename(self.calc.file)
-        else:
-            input_file_name = self.calc.name + ".xyz"
+        input_file_name = self.get_output_name()
 
         if self.calc.type in [CalcType.CONF_SEARCH, CalcType.CONSTR_CONF_SEARCH]:
             self.main_command = self.main_command.replace(
