@@ -1,6 +1,6 @@
 from ccinput.tests.testing_utilities import InputTests
 from ccinput.packages.xtb import XtbCalculation
-from ccinput.exceptions import InvalidParameter
+from ccinput.exceptions import InvalidParameter, ImpossibleCalculation
 
 
 class XtbTests(InputTests):
@@ -156,6 +156,34 @@ class XtbTests(InputTests):
         with self.assertRaises(InvalidParameter):
             xtb = self.generate_calculation(**params)
 
+    def test_solvent_change_solvation_radii(self):
+        params = {
+            "type": "Frequency Calculation",
+            "file": "Cl.xyz",
+            "software": "xtb",
+            "solvent": "chcl3",
+            "solvation_model": "ALPB",
+            "solvation_radii": "PCM",
+            "charge": "-1",
+        }
+
+        with self.assertRaises(InvalidParameter):
+            xtb = self.generate_calculation(**params)
+
+    def test_solvent_custom_solvation_radii(self):
+        params = {
+            "type": "Frequency Calculation",
+            "file": "Cl.xyz",
+            "software": "xtb",
+            "solvent": "chcl3",
+            "solvation_model": "ALPB",
+            "custom_solvation_radii": "I=3.00",
+            "charge": "-1",
+        }
+
+        with self.assertRaises(InvalidParameter):
+            xtb = self.generate_calculation(**params)
+
     def test_solvent_synonym(self):
         params = {
             "type": "Frequency Calculation",
@@ -467,6 +495,30 @@ class XtbTests(InputTests):
         """
         self.assertTrue(self.is_equivalent(INPUT, xtb.input_file))
 
+    def test_constrained_conformational_search_named_output(self):
+        params = {
+            "type": "Constrained Conformational Search",
+            "file": "ethanol.xyz",
+            "software": "xtb",
+            "constraints": "Freeze/1_2;",
+            "output": "inp",
+        }
+
+        xtb = self.generate_calculation(**params)
+
+        REF = "crest ethanol.xyz -cinp inp -rthr 0.6 -ewin 6"
+        self.assertTrue(self.is_equivalent(REF, xtb.command))
+
+        INPUT = """$constrain
+        force constant=1.0
+        reference=ethanol.xyz
+        distance: 1, 2, auto
+        atoms: 1-2
+        $metadyn
+        atoms: 3-9
+        """
+        self.assertTrue(self.is_equivalent(INPUT, xtb.input_file))
+
     def test_constrained_conformational_search_no_constraint(self):
         params = {
             "type": "Constrained Conformational Search",
@@ -650,3 +702,13 @@ class XtbTests(InputTests):
         REF = "xtb ethanol.xyz --gfnff"
 
         self.assertTrue(self.is_equivalent(REF, xtb.command))
+
+    def test_unavailable_calc_type(self):
+        params = {
+            "type": "TS Optimisation",
+            "file": "ethanol.xyz",
+            "software": "xtb",
+        }
+
+        with self.assertRaises(ImpossibleCalculation):
+            xtb = self.generate_calculation(**params)
